# -*- coding: utf-8 -*-

"""
Copyright 2023 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from .ai_pb2 import *
from .ai_pb2_grpc import *
from .actors_pb2 import *
from .actors_pb2_grpc import *
from .appcallback_pb2 import *
from .appcallback_pb2_grpc import *
from .binding_pb2 import *
from .binding_pb2_grpc import *
from .configuration_pb2 import *
from .configuration_pb2_grpc import *
from .crypto_pb2 import *
from .crypto_pb2_grpc import *
from .dapr_pb2 import *
from .dapr_pb2_grpc import *
from .invoke_pb2 import *
from .invoke_pb2_grpc import *
from .jobs_pb2 import *
from .jobs_pb2_grpc import *
from .lock_pb2 import *
from .lock_pb2_grpc import *
from .metadata_pb2 import *
from .metadata_pb2_grpc import *
from .pubsub_pb2 import *
from .pubsub_pb2_grpc import *
from .secret_pb2 import *
from .secret_pb2_grpc import *
from .state_pb2 import *
from .state_pb2_grpc import *
from .workflow_pb2 import *
from .workflow_pb2_grpc import *
