# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/secret.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/secret.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dapr/proto/runtime/v1/secret.proto\x12\x15\x64\x61pr.proto.runtime.v1\"\xb8\x01\n\x10GetSecretRequest\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12\x0b\n\x03key\x18\x02 \x01(\t\x12G\n\x08metadata\x18\x03 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.GetSecretRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x11GetSecretResponse\x12@\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.GetSecretResponse.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb3\x01\n\x14GetBulkSecretRequest\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12K\n\x08metadata\x18\x02 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.GetBulkSecretRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x0eSecretResponse\x12\x43\n\x07secrets\x18\x01 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.SecretResponse.SecretsEntry\x1a.\n\x0cSecretsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x01\n\x15GetBulkSecretResponse\x12\x44\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.dapr.proto.runtime.v1.GetBulkSecretResponse.DataEntry\x1aR\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.dapr.proto.runtime.v1.SecretResponse:\x02\x38\x01\x42i\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_GETSECRETREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_GETSECRETREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSECRETRESPONSE_DATAENTRY']._loaded_options = None
  _globals['_GETSECRETRESPONSE_DATAENTRY']._serialized_options = b'8\001'
  _globals['_GETBULKSECRETREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_GETBULKSECRETREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SECRETRESPONSE_SECRETSENTRY']._loaded_options = None
  _globals['_SECRETRESPONSE_SECRETSENTRY']._serialized_options = b'8\001'
  _globals['_GETBULKSECRETRESPONSE_DATAENTRY']._loaded_options = None
  _globals['_GETBULKSECRETRESPONSE_DATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSECRETREQUEST']._serialized_start=62
  _globals['_GETSECRETREQUEST']._serialized_end=246
  _globals['_GETSECRETREQUEST_METADATAENTRY']._serialized_start=199
  _globals['_GETSECRETREQUEST_METADATAENTRY']._serialized_end=246
  _globals['_GETSECRETRESPONSE']._serialized_start=249
  _globals['_GETSECRETRESPONSE']._serialized_end=379
  _globals['_GETSECRETRESPONSE_DATAENTRY']._serialized_start=336
  _globals['_GETSECRETRESPONSE_DATAENTRY']._serialized_end=379
  _globals['_GETBULKSECRETREQUEST']._serialized_start=382
  _globals['_GETBULKSECRETREQUEST']._serialized_end=561
  _globals['_GETBULKSECRETREQUEST_METADATAENTRY']._serialized_start=199
  _globals['_GETBULKSECRETREQUEST_METADATAENTRY']._serialized_end=246
  _globals['_SECRETRESPONSE']._serialized_start=564
  _globals['_SECRETRESPONSE']._serialized_end=697
  _globals['_SECRETRESPONSE_SECRETSENTRY']._serialized_start=651
  _globals['_SECRETRESPONSE_SECRETSENTRY']._serialized_end=697
  _globals['_GETBULKSECRETRESPONSE']._serialized_start=700
  _globals['_GETBULKSECRETRESPONSE']._serialized_end=877
  _globals['_GETBULKSECRETRESPONSE_DATAENTRY']._serialized_start=795
  _globals['_GETBULKSECRETRESPONSE_DATAENTRY']._serialized_end=877
# @@protoc_insertion_point(module_scope)
