# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/actors.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/actors.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from dapr.proto.common.v1 import common_pb2 as dapr_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dapr/proto/runtime/v1/actors.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a\x19google/protobuf/any.proto\x1a!dapr/proto/common/v1/common.proto\"\xbb\x01\n\x19RegisterActorTimerRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x08\x64ue_time\x18\x04 \x01(\tR\x07\x64ueTime\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61llback\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\x0c\x12\x0b\n\x03ttl\x18\x08 \x01(\t\"e\n\x1bUnregisterActorTimerRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xba\x02\n\x1cRegisterActorReminderRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x08\x64ue_time\x18\x04 \x01(\tR\x07\x64ueTime\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0b\n\x03ttl\x18\x07 \x01(\t\x12\x16\n\toverwrite\x18\x08 \x01(\x08H\x00\x88\x01\x01\x12S\n\x0e\x66\x61ilure_policy\x18\t \x01(\x0b\x32&.dapr.proto.common.v1.JobFailurePolicyH\x01R\x0e\x66\x61ilure_policy\x88\x01\x01\x42\x0c\n\n_overwriteB\x11\n\x0f_failure_policy\"h\n\x1eUnregisterActorReminderRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0c\n\x04name\x18\x03 \x01(\t\"]\n\x14GetActorStateRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xa4\x01\n\x15GetActorStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12L\n\x08metadata\x18\x02 \x03(\x0b\x32:.dapr.proto.runtime.v1.GetActorStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x01\n#ExecuteActorStateTransactionRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12K\n\noperations\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.TransactionalActorStateOperation\"\xf5\x01\n TransactionalActorStateOperation\x12\x15\n\roperationType\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12#\n\x05value\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12W\n\x08metadata\x18\x04 \x03(\x0b\x32\x45.dapr.proto.runtime.v1.TransactionalActorStateOperation.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe8\x01\n\x12InvokeActorRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.InvokeActorRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"#\n\x13InvokeActorResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"a\n\x17GetActorReminderRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torID\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xdf\x01\n\x18GetActorReminderResponse\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torID\x12\x1e\n\x08\x64ue_time\x18\x04 \x01(\tH\x00R\x07\x64ueTime\x88\x01\x01\x12\x13\n\x06period\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\"\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x10\n\x03ttl\x18\x07 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_due_timeB\t\n\x07_periodB\x06\n\x04_ttl\"g\n\x19ListActorRemindersRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x1e\n\x08\x61\x63tor_id\x18\x02 \x01(\tH\x00R\x07\x61\x63torId\x88\x01\x01\x42\x0b\n\t_actor_id\"Z\n\x1aListActorRemindersResponse\x12<\n\treminders\x18\x01 \x03(\x0b\x32).dapr.proto.runtime.v1.NamedActorReminder\"Z\n\x12NamedActorReminder\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x08reminder\x18\x02 \x01(\x0b\x32$.dapr.proto.runtime.v1.ActorReminder\"\xd4\x01\n\rActorReminder\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torID\x12\x1e\n\x08\x64ue_time\x18\x04 \x01(\tH\x00R\x07\x64ueTime\x88\x01\x01\x12\x13\n\x06period\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\"\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x10\n\x03ttl\x18\x07 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_due_timeB\t\n\x07_periodB\x06\n\x04_ttl\"s\n%UnregisterActorRemindersByTypeRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x1e\n\x08\x61\x63tor_id\x18\x02 \x01(\tH\x00R\x07\x61\x63torId\x88\x01\x01\x42\x0b\n\t_actor_id\"(\n&UnregisterActorRemindersByTypeResponseBi\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.actors_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_GETACTORSTATERESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_GETACTORSTATERESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_TRANSACTIONALACTORSTATEOPERATION_METADATAENTRY']._loaded_options = None
  _globals['_TRANSACTIONALACTORSTATEOPERATION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INVOKEACTORREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_INVOKEACTORREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_REGISTERACTORTIMERREQUEST']._serialized_start=124
  _globals['_REGISTERACTORTIMERREQUEST']._serialized_end=311
  _globals['_UNREGISTERACTORTIMERREQUEST']._serialized_start=313
  _globals['_UNREGISTERACTORTIMERREQUEST']._serialized_end=414
  _globals['_REGISTERACTORREMINDERREQUEST']._serialized_start=417
  _globals['_REGISTERACTORREMINDERREQUEST']._serialized_end=731
  _globals['_UNREGISTERACTORREMINDERREQUEST']._serialized_start=733
  _globals['_UNREGISTERACTORREMINDERREQUEST']._serialized_end=837
  _globals['_GETACTORSTATEREQUEST']._serialized_start=839
  _globals['_GETACTORSTATEREQUEST']._serialized_end=932
  _globals['_GETACTORSTATERESPONSE']._serialized_start=935
  _globals['_GETACTORSTATERESPONSE']._serialized_end=1099
  _globals['_GETACTORSTATERESPONSE_METADATAENTRY']._serialized_start=1052
  _globals['_GETACTORSTATERESPONSE_METADATAENTRY']._serialized_end=1099
  _globals['_EXECUTEACTORSTATETRANSACTIONREQUEST']._serialized_start=1102
  _globals['_EXECUTEACTORSTATETRANSACTIONREQUEST']._serialized_end=1274
  _globals['_TRANSACTIONALACTORSTATEOPERATION']._serialized_start=1277
  _globals['_TRANSACTIONALACTORSTATEOPERATION']._serialized_end=1522
  _globals['_TRANSACTIONALACTORSTATEOPERATION_METADATAENTRY']._serialized_start=1052
  _globals['_TRANSACTIONALACTORSTATEOPERATION_METADATAENTRY']._serialized_end=1099
  _globals['_INVOKEACTORREQUEST']._serialized_start=1525
  _globals['_INVOKEACTORREQUEST']._serialized_end=1757
  _globals['_INVOKEACTORREQUEST_METADATAENTRY']._serialized_start=1052
  _globals['_INVOKEACTORREQUEST_METADATAENTRY']._serialized_end=1099
  _globals['_INVOKEACTORRESPONSE']._serialized_start=1759
  _globals['_INVOKEACTORRESPONSE']._serialized_end=1794
  _globals['_GETACTORREMINDERREQUEST']._serialized_start=1796
  _globals['_GETACTORREMINDERREQUEST']._serialized_end=1893
  _globals['_GETACTORREMINDERRESPONSE']._serialized_start=1896
  _globals['_GETACTORREMINDERRESPONSE']._serialized_end=2119
  _globals['_LISTACTORREMINDERSREQUEST']._serialized_start=2121
  _globals['_LISTACTORREMINDERSREQUEST']._serialized_end=2224
  _globals['_LISTACTORREMINDERSRESPONSE']._serialized_start=2226
  _globals['_LISTACTORREMINDERSRESPONSE']._serialized_end=2316
  _globals['_NAMEDACTORREMINDER']._serialized_start=2318
  _globals['_NAMEDACTORREMINDER']._serialized_end=2408
  _globals['_ACTORREMINDER']._serialized_start=2411
  _globals['_ACTORREMINDER']._serialized_end=2623
  _globals['_UNREGISTERACTORREMINDERSBYTYPEREQUEST']._serialized_start=2625
  _globals['_UNREGISTERACTORREMINDERSBYTYPEREQUEST']._serialized_end=2740
  _globals['_UNREGISTERACTORREMINDERSBYTYPERESPONSE']._serialized_start=2742
  _globals['_UNREGISTERACTORREMINDERSBYTYPERESPONSE']._serialized_end=2782
# @@protoc_insertion_point(module_scope)
