# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/state.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dapr.proto.common.v1 import common_pb2 as dapr_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dapr/proto/runtime/v1/state.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a!dapr/proto/common/v1/common.proto\"\xf5\x01\n\x0fGetStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12H\n\x0b\x63onsistency\x18\x03 \x01(\x0e\x32\x33.dapr.proto.common.v1.StateOptions.StateConsistency\x12\x46\n\x08metadata\x18\x04 \x03(\x0b\x32\x34.dapr.proto.runtime.v1.GetStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc9\x01\n\x13GetBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x13\n\x0bparallelism\x18\x03 \x01(\x05\x12J\n\x08metadata\x18\x04 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.GetBulkStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"K\n\x14GetBulkStateResponse\x12\x33\n\x05items\x18\x01 \x03(\x0b\x32$.dapr.proto.runtime.v1.BulkStateItem\"\xbe\x01\n\rBulkStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\x12\x44\n\x08metadata\x18\x05 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.BulkStateItem.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\x10GetStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12G\n\x08metadata\x18\x03 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.GetStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x02\n\x12\x44\x65leteStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12(\n\x04\x65tag\x18\x03 \x01(\x0b\x32\x1a.dapr.proto.common.v1.Etag\x12\x33\n\x07options\x18\x04 \x01(\x0b\x32\".dapr.proto.common.v1.StateOptions\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.DeleteStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x16\x44\x65leteBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"W\n\x10SaveStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\xbc\x01\n\x11QueryStateRequest\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12\r\n\x05query\x18\x02 \x01(\t\x12H\n\x08metadata\x18\x03 \x03(\x0b\x32\x36.dapr.proto.runtime.v1.QueryStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x0eQueryStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xd7\x01\n\x12QueryStateResponse\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.dapr.proto.runtime.v1.QueryStateItem\x12\r\n\x05token\x18\x02 \x01(\t\x12I\n\x08metadata\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.QueryStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x1bTransactionalStateOperation\x12\x15\n\roperationType\x18\x01 \x01(\t\x12\x30\n\x07request\x18\x02 \x01(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\x83\x02\n\x1e\x45xecuteStateTransactionRequest\x12\x11\n\tstoreName\x18\x01 \x01(\t\x12\x46\n\noperations\x18\x02 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.TransactionalStateOperation\x12U\n\x08metadata\x18\x03 \x03(\x0b\x32\x43.dapr.proto.runtime.v1.ExecuteStateTransactionRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42i\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_GETSTATEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_GETSTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_BULKSTATEITEM_METADATAENTRY']._loaded_options = None
  _globals['_BULKSTATEITEM_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATERESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_GETSTATERESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATEREQUEST']._serialized_start=96
  _globals['_GETSTATEREQUEST']._serialized_end=341
  _globals['_GETSTATEREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_GETSTATEREQUEST_METADATAENTRY']._serialized_end=341
  _globals['_GETBULKSTATEREQUEST']._serialized_start=344
  _globals['_GETBULKSTATEREQUEST']._serialized_end=545
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._serialized_end=341
  _globals['_GETBULKSTATERESPONSE']._serialized_start=547
  _globals['_GETBULKSTATERESPONSE']._serialized_end=622
  _globals['_BULKSTATEITEM']._serialized_start=625
  _globals['_BULKSTATEITEM']._serialized_end=815
  _globals['_BULKSTATEITEM_METADATAENTRY']._serialized_start=294
  _globals['_BULKSTATEITEM_METADATAENTRY']._serialized_end=341
  _globals['_GETSTATERESPONSE']._serialized_start=818
  _globals['_GETSTATERESPONSE']._serialized_end=986
  _globals['_GETSTATERESPONSE_METADATAENTRY']._serialized_start=294
  _globals['_GETSTATERESPONSE_METADATAENTRY']._serialized_end=341
  _globals['_DELETESTATEREQUEST']._serialized_start=989
  _globals['_DELETESTATEREQUEST']._serialized_end=1261
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._serialized_end=341
  _globals['_DELETEBULKSTATEREQUEST']._serialized_start=1263
  _globals['_DELETEBULKSTATEREQUEST']._serialized_end=1356
  _globals['_SAVESTATEREQUEST']._serialized_start=1358
  _globals['_SAVESTATEREQUEST']._serialized_end=1445
  _globals['_QUERYSTATEREQUEST']._serialized_start=1448
  _globals['_QUERYSTATEREQUEST']._serialized_end=1636
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._serialized_end=341
  _globals['_QUERYSTATEITEM']._serialized_start=1638
  _globals['_QUERYSTATEITEM']._serialized_end=1710
  _globals['_QUERYSTATERESPONSE']._serialized_start=1713
  _globals['_QUERYSTATERESPONSE']._serialized_end=1928
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._serialized_start=294
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._serialized_end=341
  _globals['_TRANSACTIONALSTATEOPERATION']._serialized_start=1930
  _globals['_TRANSACTIONALSTATEOPERATION']._serialized_end=2032
  _globals['_EXECUTESTATETRANSACTIONREQUEST']._serialized_start=2035
  _globals['_EXECUTESTATETRANSACTIONREQUEST']._serialized_end=2294
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._serialized_end=341
# @@protoc_insertion_point(module_scope)
