# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/ai.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/ai.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64\x61pr/proto/runtime/v1/ai.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xeb\x03\n\x13\x43onversationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\tcontextID\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x06inputs\x18\x03 \x03(\x0b\x32(.dapr.proto.runtime.v1.ConversationInput\x12N\n\nparameters\x18\x04 \x03(\x0b\x32:.dapr.proto.runtime.v1.ConversationRequest.ParametersEntry\x12J\n\x08metadata\x18\x05 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.ConversationRequest.MetadataEntry\x12\x15\n\x08scrubPII\x18\x06 \x01(\x08H\x01\x88\x01\x01\x12\x18\n\x0btemperature\x18\x07 \x01(\x01H\x02\x88\x01\x01\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\x02\x18\x01\x42\x0c\n\n_contextIDB\x0b\n\t_scrubPIIB\x0e\n\x0c_temperature\"\xe6\x04\n\x19\x43onversationRequestAlpha2\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\ncontext_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12>\n\x06inputs\x18\x03 \x03(\x0b\x32..dapr.proto.runtime.v1.ConversationInputAlpha2\x12T\n\nparameters\x18\x04 \x03(\x0b\x32@.dapr.proto.runtime.v1.ConversationRequestAlpha2.ParametersEntry\x12P\n\x08metadata\x18\x05 \x03(\x0b\x32>.dapr.proto.runtime.v1.ConversationRequestAlpha2.MetadataEntry\x12\x16\n\tscrub_pii\x18\x06 \x01(\x08H\x01\x88\x01\x01\x12\x18\n\x0btemperature\x18\x07 \x01(\x01H\x02\x88\x01\x01\x12\x37\n\x05tools\x18\x08 \x03(\x0b\x32(.dapr.proto.runtime.v1.ConversationTools\x12\x18\n\x0btool_choice\x18\t \x01(\tH\x03\x88\x01\x01\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0b_context_idB\x0c\n\n_scrub_piiB\x0e\n\x0c_temperatureB\x0e\n\x0c_tool_choice\"h\n\x11\x43onversationInput\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\x04role\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08scrubPII\x18\x03 \x01(\x08H\x01\x88\x01\x01:\x02\x18\x01\x42\x07\n\x05_roleB\x0b\n\t_scrubPII\"}\n\x17\x43onversationInputAlpha2\x12<\n\x08messages\x18\x01 \x03(\x0b\x32*.dapr.proto.runtime.v1.ConversationMessage\x12\x16\n\tscrub_pii\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x0c\n\n_scrub_pii\"\x97\x03\n\x13\x43onversationMessage\x12M\n\x0cof_developer\x18\x01 \x01(\x0b\x32\x35.dapr.proto.runtime.v1.ConversationMessageOfDeveloperH\x00\x12G\n\tof_system\x18\x02 \x01(\x0b\x32\x32.dapr.proto.runtime.v1.ConversationMessageOfSystemH\x00\x12\x43\n\x07of_user\x18\x03 \x01(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationMessageOfUserH\x00\x12M\n\x0cof_assistant\x18\x04 \x01(\x0b\x32\x35.dapr.proto.runtime.v1.ConversationMessageOfAssistantH\x00\x12\x43\n\x07of_tool\x18\x05 \x01(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationMessageOfToolH\x00\x42\x0f\n\rmessage_types\"\x80\x01\n\x1e\x43onversationMessageOfDeveloper\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContentB\x07\n\x05_name\"}\n\x1b\x43onversationMessageOfSystem\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContentB\x07\n\x05_name\"{\n\x19\x43onversationMessageOfUser\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContentB\x07\n\x05_name\"\xc2\x01\n\x1e\x43onversationMessageOfAssistant\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContent\x12@\n\ntool_calls\x18\x03 \x03(\x0b\x32,.dapr.proto.runtime.v1.ConversationToolCallsB\x07\n\x05_name\"\x8f\x01\n\x19\x43onversationMessageOfTool\x12\x14\n\x07tool_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\x07\x63ontent\x18\x03 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContentB\n\n\x08_tool_id\"\x89\x01\n\x15\x43onversationToolCalls\x12\x0f\n\x02id\x18\x01 \x01(\tH\x01\x88\x01\x01\x12J\n\x08\x66unction\x18\x02 \x01(\x0b\x32\x36.dapr.proto.runtime.v1.ConversationToolCallsOfFunctionH\x00\x42\x0c\n\ntool_typesB\x05\n\x03_id\"B\n\x1f\x43onversationToolCallsOfFunction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x01(\t\"*\n\x1a\x43onversationMessageContent\x12\x0c\n\x04text\x18\x01 \x01(\t\"\xc0\x01\n\x12\x43onversationResult\x12\x0e\n\x06result\x18\x01 \x01(\t\x12M\n\nparameters\x18\x02 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.ConversationResult.ParametersEntry\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01:\x02\x18\x01\"]\n\x18\x43onversationResultAlpha2\x12\x41\n\x07\x63hoices\x18\x01 \x03(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationResultChoices\"\x84\x01\n\x19\x43onversationResultChoices\x12\x15\n\rfinish_reason\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x03\x12\x41\n\x07message\x18\x03 \x01(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationResultMessage\"n\n\x19\x43onversationResultMessage\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12@\n\ntool_calls\x18\x02 \x03(\x0b\x32,.dapr.proto.runtime.v1.ConversationToolCalls\"|\n\x14\x43onversationResponse\x12\x16\n\tcontextID\x18\x01 \x01(\tH\x00\x88\x01\x01\x12:\n\x07outputs\x18\x02 \x03(\x0b\x32).dapr.proto.runtime.v1.ConversationResult:\x02\x18\x01\x42\x0c\n\n_contextID\"\x86\x01\n\x1a\x43onversationResponseAlpha2\x12\x17\n\ncontext_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12@\n\x07outputs\x18\x02 \x03(\x0b\x32/.dapr.proto.runtime.v1.ConversationResultAlpha2B\r\n\x0b_context_id\"g\n\x11\x43onversationTools\x12\x44\n\x08\x66unction\x18\x01 \x01(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationToolsFunctionH\x00\x42\x0c\n\ntool_types\"\x80\x01\n\x19\x43onversationToolsFunction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12+\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x0e\n\x0c_descriptionBi\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.ai_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONREQUEST']._loaded_options = None
  _globals['_CONVERSATIONREQUEST']._serialized_options = b'\030\001'
  _globals['_CONVERSATIONREQUESTALPHA2_PARAMETERSENTRY']._loaded_options = None
  _globals['_CONVERSATIONREQUESTALPHA2_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONREQUESTALPHA2_METADATAENTRY']._loaded_options = None
  _globals['_CONVERSATIONREQUESTALPHA2_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONINPUT']._loaded_options = None
  _globals['_CONVERSATIONINPUT']._serialized_options = b'\030\001'
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._loaded_options = None
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONRESULT']._loaded_options = None
  _globals['_CONVERSATIONRESULT']._serialized_options = b'\030\001'
  _globals['_CONVERSATIONRESPONSE']._loaded_options = None
  _globals['_CONVERSATIONRESPONSE']._serialized_options = b'\030\001'
  _globals['_CONVERSATIONREQUEST']._serialized_start=115
  _globals['_CONVERSATIONREQUEST']._serialized_end=606
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._serialized_start=439
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._serialized_end=510
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._serialized_start=512
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._serialized_end=559
  _globals['_CONVERSATIONREQUESTALPHA2']._serialized_start=609
  _globals['_CONVERSATIONREQUESTALPHA2']._serialized_end=1223
  _globals['_CONVERSATIONREQUESTALPHA2_PARAMETERSENTRY']._serialized_start=439
  _globals['_CONVERSATIONREQUESTALPHA2_PARAMETERSENTRY']._serialized_end=510
  _globals['_CONVERSATIONREQUESTALPHA2_METADATAENTRY']._serialized_start=512
  _globals['_CONVERSATIONREQUESTALPHA2_METADATAENTRY']._serialized_end=559
  _globals['_CONVERSATIONINPUT']._serialized_start=1225
  _globals['_CONVERSATIONINPUT']._serialized_end=1329
  _globals['_CONVERSATIONINPUTALPHA2']._serialized_start=1331
  _globals['_CONVERSATIONINPUTALPHA2']._serialized_end=1456
  _globals['_CONVERSATIONMESSAGE']._serialized_start=1459
  _globals['_CONVERSATIONMESSAGE']._serialized_end=1866
  _globals['_CONVERSATIONMESSAGEOFDEVELOPER']._serialized_start=1869
  _globals['_CONVERSATIONMESSAGEOFDEVELOPER']._serialized_end=1997
  _globals['_CONVERSATIONMESSAGEOFSYSTEM']._serialized_start=1999
  _globals['_CONVERSATIONMESSAGEOFSYSTEM']._serialized_end=2124
  _globals['_CONVERSATIONMESSAGEOFUSER']._serialized_start=2126
  _globals['_CONVERSATIONMESSAGEOFUSER']._serialized_end=2249
  _globals['_CONVERSATIONMESSAGEOFASSISTANT']._serialized_start=2252
  _globals['_CONVERSATIONMESSAGEOFASSISTANT']._serialized_end=2446
  _globals['_CONVERSATIONMESSAGEOFTOOL']._serialized_start=2449
  _globals['_CONVERSATIONMESSAGEOFTOOL']._serialized_end=2592
  _globals['_CONVERSATIONTOOLCALLS']._serialized_start=2595
  _globals['_CONVERSATIONTOOLCALLS']._serialized_end=2732
  _globals['_CONVERSATIONTOOLCALLSOFFUNCTION']._serialized_start=2734
  _globals['_CONVERSATIONTOOLCALLSOFFUNCTION']._serialized_end=2800
  _globals['_CONVERSATIONMESSAGECONTENT']._serialized_start=2802
  _globals['_CONVERSATIONMESSAGECONTENT']._serialized_end=2844
  _globals['_CONVERSATIONRESULT']._serialized_start=2847
  _globals['_CONVERSATIONRESULT']._serialized_end=3039
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._serialized_start=439
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._serialized_end=510
  _globals['_CONVERSATIONRESULTALPHA2']._serialized_start=3041
  _globals['_CONVERSATIONRESULTALPHA2']._serialized_end=3134
  _globals['_CONVERSATIONRESULTCHOICES']._serialized_start=3137
  _globals['_CONVERSATIONRESULTCHOICES']._serialized_end=3269
  _globals['_CONVERSATIONRESULTMESSAGE']._serialized_start=3271
  _globals['_CONVERSATIONRESULTMESSAGE']._serialized_end=3381
  _globals['_CONVERSATIONRESPONSE']._serialized_start=3383
  _globals['_CONVERSATIONRESPONSE']._serialized_end=3507
  _globals['_CONVERSATIONRESPONSEALPHA2']._serialized_start=3510
  _globals['_CONVERSATIONRESPONSEALPHA2']._serialized_end=3644
  _globals['_CONVERSATIONTOOLS']._serialized_start=3646
  _globals['_CONVERSATIONTOOLS']._serialized_end=3749
  _globals['_CONVERSATIONTOOLSFUNCTION']._serialized_start=3752
  _globals['_CONVERSATIONTOOLSFUNCTION']._serialized_end=3880
# @@protoc_insertion_point(module_scope)
