# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/binding.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/binding.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dapr/proto/runtime/v1/binding.proto\x12\x15\x64\x61pr.proto.runtime.v1\"\xc3\x01\n\x14InvokeBindingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12K\n\x08metadata\x18\x03 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.InvokeBindingRequest.MetadataEntry\x12\x11\n\toperation\x18\x04 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x15InvokeBindingResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12L\n\x08metadata\x18\x02 \x03(\x0b\x32:.dapr.proto.runtime.v1.InvokeBindingResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42i\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.binding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INVOKEBINDINGREQUEST']._serialized_start=63
  _globals['_INVOKEBINDINGREQUEST']._serialized_end=258
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._serialized_start=211
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._serialized_end=258
  _globals['_INVOKEBINDINGRESPONSE']._serialized_start=261
  _globals['_INVOKEBINDINGRESPONSE']._serialized_end=425
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._serialized_start=211
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._serialized_end=258
# @@protoc_insertion_point(module_scope)
